from bluer_options.env import load_config, load_env, get_env

load_env(__name__)
load_config(__name__)

BLUER_AGENT_API_KEY = get_env("BLUER_AGENT_API_KEY")

BLUER_AGENT_AUDIO_TEST_OBJECT = get_env("BLUER_AGENT_AUDIO_TEST_OBJECT")

BLUER_AGENT_CHAT_ENDPOINT = get_env("BLUER_AGENT_CHAT_ENDPOINT")
BLUER_AGENT_CHAT_MAX_TOKENS = get_env("BLUER_AGENT_CHAT_MAX_TOKENS", 3000)
BLUER_AGENT_CHAT_MODEL_NAME = get_env("BLUER_AGENT_CHAT_MODEL_NAME")
BLUER_AGENT_CHAT_TEMPERATURE = get_env("BLUER_AGENT_CHAT_TEMPERATURE", 0.7)
BLUER_AGENT_CHAT_TIMEOUT = get_env("BLUER_AGENT_CHAT_TIMEOUT", 60)

BLUER_AGENT_CRAWL_TEST_OBJECT = get_env(
    "BLUER_AGENT_CRAWL_TEST_OBJECT",
)
BLUER_AGENT_CRAWL_SINGLE_ROOT_TEST_OBJECT = get_env(
    "BLUER_AGENT_CRAWL_SINGLE_ROOT_TEST_OBJECT"
)

BLUER_AGENT_MACHINE_USER_NAME = get_env("BLUER_AGENT_MACHINE_USER_NAME")

BLUER_AGENT_EMBEDDING_MODEL_NAME = get_env("BLUER_AGENT_EMBEDDING_MODEL_NAME")
BLUER_AGENT_EMBEDDING_ENDPOINT = get_env("BLUER_AGENT_EMBEDDING_ENDPOINT")

BLUER_AGENT_RAG_CORPUS_TEST_OBJECT = get_env(
    "BLUER_AGENT_RAG_CORPUS_TEST_OBJECT",
)
BLUER_AGENT_RAG_CORPUS_SINGLE_ROOT_TEST_OBJECT = get_env(
    "BLUER_AGENT_RAG_CORPUS_SINGLE_ROOT_TEST_OBJECT",
)

BLUER_AGENT_TRANSCRIPTION_ENDPOINT = get_env("BLUER_AGENT_TRANSCRIPTION_ENDPOINT")
BLUER_AGENT_TRANSCRIPTION_MODEL_NAME = get_env("BLUER_AGENT_TRANSCRIPTION_MODEL_NAME")
BLUER_AGENT_TRANSCRIPTION_RETRIAL = get_env("BLUER_AGENT_TRANSCRIPTION_RETRIAL", 5)
BLUER_AGENT_TRANSCRIPTION_TEST_OBJECT = get_env("BLUER_AGENT_TRANSCRIPTION_TEST_OBJECT")

BLUER_AGENT_VOICE_ENDPOINT = get_env("BLUER_AGENT_VOICE_ENDPOINT")
BLUER_AGENT_VOICE_TOKEN = get_env("BLUER_AGENT_VOICE_TOKEN")


BLUER_AGENT_ASSISTANT_PORT = get_env(
    "BLUER_AGENT_ASSISTANT_PORT",
    5100,
)
BLUER_AGENT_ASSISTANT_CACHE = get_env("BLUER_AGENT_ASSISTANT_CACHE")
