# Thresholds: percent of full scale. Try 1%..5%.
# how loud to begin
BLUER_AGENT_AUDIO_LISTEN_START_THRESHOLD = "5%"
# how quiet to consider silence
BLUER_AGENT_AUDIO_LISTEN_STOP_THRESHOLD = "5%"

# durations:
# need this long above threshold to start (sec)
BLUER_AGENT_AUDIO_LISTEN_START_HOLD = "0.10"
# stop after this long below threshold (sec)
BLUER_AGENT_AUDIO_LISTEN_STOP_HOLD = "1.20"
